pyfurc API Reference
====================
                This is the reference page for classes and methods in the
                pyfurc package. It is automatically rendered from
                docstrings in the source code.

.. automodule:: pyfurc
   :members:
   :undoc-members:
   :show-inheritance:


pyfurc.core module
------------------

.. automodule:: pyfurc.core
   :members:
   :undoc-members:
   :show-inheritance:

pyfurc.tools module
-------------------

.. automodule:: pyfurc.tools
   :members:
   :undoc-members:
   :show-inheritance:

pyfurc.util module
------------------

.. automodule:: pyfurc.util
   :members:
   :undoc-members:
   :show-inheritance:
